===============================
dj-oydiv
===============================

.. image:: https://img.shields.io/travis/ajenta/dj-oydiv.svg
        :target: https://travis-ci.org/ajenta/dj-oydiv

.. image:: https://img.shields.io/pypi/v/dj-oydiv.svg
        :target: https://pypi.python.org/pypi/dj-oydiv


dj-oydiv is a django app that simplifies videoconferencing with Vidyo.

* Free software: BSD license
* Documentation: https://dj-oydiv.readthedocs.org.

Features
--------

* TODO
